@@ -1,13 +1,16 @@
 package DBIx::Class::Helper::ResultSet::IgnoreWantarray;
+$DBIx::Class::Helper::ResultSet::IgnoreWantarray::VERSION = '2.030000';
+# ABSTRACT: Get rid of search context issues
 
 use strict;
 use warnings;
 
-# ABSTRACT: Get rid of search context issues
-
-our $VERSION = '2.019002'; # VERSION
+use parent 'DBIx::Class::ResultSet';
 
 sub search {
+   $_[0]->throw_exception ('->search is *not* a mutator, calling it in void context makes no sense')
+      if !defined wantarray && (caller)[0] !~ /^\QDBIx::Class::/;
+
    shift->search_rs(@_);
 }
 
@@ -17,16 +20,10 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 DBIx::Class::Helper::ResultSet::IgnoreWantarray - Get rid of search context issues
 
-=head1 VERSION
-
-version 2.019002
-
 =head1 SYNOPSIS
 
  package MyApp::Schema::ResultSet::Foo;
@@ -64,7 +61,7 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2015 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
