@@ -1,11 +1,11 @@
 package DBIx::Class::Helper::ResultSet::Shortcut;
-$DBIx::Class::Helper::ResultSet::Shortcut::VERSION = '2.023007';
+$DBIx::Class::Helper::ResultSet::Shortcut::VERSION = '2.030000';
 # ABSTRACT: Shortcuts to common searches (->order_by, etc)
 
 use strict;
 use warnings;
 
-use base (qw(
+use parent (qw(
    DBIx::Class::Helper::ResultSet::Shortcut::AddColumns
    DBIx::Class::Helper::ResultSet::Shortcut::Columns
    DBIx::Class::Helper::ResultSet::Shortcut::Distinct
@@ -19,6 +19,7 @@ use base (qw(
    DBIx::Class::Helper::ResultSet::Shortcut::ResultsExist
    DBIx::Class::Helper::ResultSet::Shortcut::Rows
    DBIx::Class::Helper::ResultSet::Shortcut::Page
+   DBIx::Class::Helper::ResultSet::Shortcut::Search
 ));
 
 1;
@@ -218,13 +219,33 @@ Uses C<EXISTS> SQL function to check if the query would return anything.
 Possibly lighter weight than the much more common C<< foo() if $rs->count >>
 idiom.
 
+=head2 null(@columns || \@columns)
+
+ $rs->null('status');
+ $rs->null(['status', 'title']);
+
+=head2 not_null(@columns || \@columns)
+
+ $rs->not_null('status');
+ $rs->not_null(['status', 'title']);
+
+=head2 like($column || \@columns, $cond)
+
+ $rs->like('lyrics', '%zebra%');
+ $rs->like(['lyrics', 'title'], '%zebra%');
+
+=head2 not_like($column || \@columns, $cond)
+
+ $rs->not_like('lyrics', '%zebra%');
+ $rs->not_like(['lyrics', 'title'], '%zebra%');
+
 =head1 AUTHOR
 
 Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2015 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
