@@ -1,8 +1,11 @@
 package DBIx::Class::Helper::Row::ProxyResultSetUpdate;
-$DBIx::Class::Helper::Row::ProxyResultSetUpdate::VERSION = '2.023007';
+$DBIx::Class::Helper::Row::ProxyResultSetUpdate::VERSION = '2.030000';
 # ABSTRACT: Efficiently reuse ResultSet updates from results
 
-use base 'DBIx::Class::Helper::Row::SelfResultSet';
+use strict;
+use warnings;
+
+use parent 'DBIx::Class::Helper::Row::SelfResultSet', 'DBIx::Class::Row';
 
 sub update {
   my ($self, $upd) = @_;
@@ -43,7 +46,7 @@ ResultSet:
 
  package MyApp::Schema::ResultSet::Foo;
 
- use base 'DBIx::Class::ResultSet';
+ use parent 'DBIx::Class::ResultSet';
 
  sub update {
     my ($self, $data) = @_;
@@ -57,7 +60,7 @@ Result:
 
  package MyApp::Schema::Result::Foo;
 
- use base 'DBIx::Class::Core';
+ use parent 'DBIx::Class::Core';
 
  __PACKAGE__->load_components(qw( Helper::Row::ProxyResultSetUpdate ));
 
@@ -86,7 +89,7 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2015 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
